# PyConfs

_Unified handling of configuration files in Python_

[![Latest version](https://img.shields.io/pypi/v/pyconfs.svg)](https://pypi.org/project/pyconfs/)
[![Python versions](https://img.shields.io/pypi/pyversions/pyconfs.svg)](https://pypi.org/project/pyconfs/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![CircleCI](https://circleci.com/gh/gahjelle/pyconfs.svg?style=shield)](https://circleci.com/gh/gahjelle/pyconfs)

## Installing PyConfs

PyConfs is available at [PyPI](https://pypi.org/project/pyconfs/). You can install it using Pip:

    $ python -m pip install pyconfs


## Using PyConfs

...


## Installing From Source

You can always download the [latest version of PyConfs from GitHub](https://github.com/gahjelle/pyconfs). PyConfs uses [Flit](https://flit.readthedocs.io/) as a setup tool.

To install PyConfs from the downloaded source, run Flit:

    $ python -m flit install --deps production

If you want to change and play with the PyConfs source code, you should install it in editable mode:

    $ python -m flit install --symlink